@@ -1,6 +1,5 @@
-use crate::imp;
+use crate::{imp, io::RawFd};
 use io_lifetimes::BorrowedFd;
-use unsafe_io::os::posish::RawFd;
 
 /// `AT_FDCWD`
 ///
