@@ -85,6 +85,11 @@ unsafe fn init_from_sysinfo_ehdr(base: usize) -> Option<Vdso> {
     if hdr.e_type != ET_DYN {
         return None; // Wrong ELF type
     }
+    // Verify that the `e_machine` matches the architecture we're running as.
+    // This helps catch cases where we're running under qemu.
+    if hdr.e_machine != EM_CURRENT {
+        return None; // Wrong machine type
+    }
 
     // If ELF is extended, we'll need to adjust.
     if hdr.e_ident[EI_VERSION] != EV_CURRENT
@@ -330,6 +335,12 @@ const STN_UNDEF: u32 = 0;
 const VER_FLG_BASE: u16 = 0x1;
 const VER_DEF_CURRENT: u16 = 1;
 const STV_DEFAULT: u8 = 0;
+#[cfg(target_arch = "x86")]
+const EM_CURRENT: u16 = 3; // EM_386
+#[cfg(target_arch = "x86_64")]
+const EM_CURRENT: u16 = 62; // EM_X86_64
+#[cfg(target_arch = "aarch64")]
+const EM_CURRENT: u16 = 183; // EM_AARCH64
 
 #[inline]
 fn ELF_ST_VISIBILITY(o: u8) -> u8 {
